==> ask-smapi-model-1.8.1.tar.gz: ask-smapi-model-1.8.1/ask_smapi_model/v1/skill/manifest/__init__.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .connections_payload import ConnectionsPayload
from .flash_briefing_update_frequency import FlashBriefingUpdateFrequency
from .skill_manifest_localized_privacy_and_compliance import SkillManifestLocalizedPrivacyAndCompliance
from .music_feature import MusicFeature
from .skill_manifest_endpoint import SkillManifestEndpoint
from .health_apis import HealthApis
from .ssl_certificate_type import SSLCertificateType
from .viewport_mode import ViewportMode
from .skill_manifest_events import SkillManifestEvents
from .flash_briefing_content_type import FlashBriefingContentType
from .health_alias import HealthAlias
from .skill_manifest_privacy_and_compliance import SkillManifestPrivacyAndCompliance
from .music_apis import MusicApis
from .distribution_mode import DistributionMode
from .custom_connections import CustomConnections
from .music_capability import MusicCapability
from .display_interface_apml_version import DisplayInterfaceApmlVersion
from .event_name import EventName
from .up_channel_items import UpChannelItems
from .house_hold_list import HouseHoldList
from .music_interfaces import MusicInterfaces
from .permission_name import PermissionName
from .interface import Interface
from .health_interface import HealthInterface
from .region import Region
from .skill_manifest_envelope import SkillManifestEnvelope
from .skill_manifest_apis import SkillManifestApis
from .connections import Connections
from .lambda_endpoint import LambdaEndpoint
from .viewport_specification import ViewportSpecification
from .music_alias import MusicAlias
from .request_name import RequestName
from .music_content_type import MusicContentType
from .manifest_gadget_support import ManifestGadgetSupport
from .custom_interface import CustomInterface
from .distribution_countries import DistributionCountries
from .skill_manifest_publishing_information import SkillManifestPublishingInformation
from .health_protocol_version import HealthProtocolVersion
from .video_app_interface import VideoAppInterface
from .custom_apis import CustomApis
from .flash_briefing_genre import FlashBriefingGenre
from .localized_flash_briefing_info_items import LocalizedFlashBriefingInfoItems
from .music_wordmark import MusicWordmark
from .video_apis_locale import VideoApisLocale
from .health_request import HealthRequest
from .alexa_for_business_interface import AlexaForBusinessInterface
from .game_engine_interface import GameEngineInterface
from .gadget_controller_interface import GadgetControllerInterface
from .smart_home_protocol import SmartHomeProtocol
from .skill_manifest_localized_publishing_information import SkillManifestLocalizedPublishingInformation
from .version import Version
from .music_request import MusicRequest
from .video_apis import VideoApis
from .gadget_support import GadgetSupport
from .lambda_region import LambdaRegion
from .video_country_info import VideoCountryInfo
from .skill_manifest import SkillManifest
from .flash_briefing_apis import FlashBriefingApis
from .skill_manifest_custom_task import SkillManifestCustomTask
from .permission_items import PermissionItems
from .localized_health_info import LocalizedHealthInfo
from .event_name_type import EventNameType
from .audio_interface import AudioInterface
from .smart_home_apis import SmartHomeApis
from .alexa_for_business_apis import AlexaForBusinessApis
from .video_region import VideoRegion
from .viewport_shape import ViewportShape
from .alexa_presentation_apl_interface import AlexaPresentationAplInterface
from .display_interface import DisplayInterface
from .music_content_name import MusicContentName
from .display_interface_template_version import DisplayInterfaceTemplateVersion
from .request import Request
from .event_publications import EventPublications
from .localized_music_info import LocalizedMusicInfo
from .video_catalog_info import VideoCatalogInfo
from .localized_flash_briefing_info import LocalizedFlashBriefingInfo
from .alexa_presentation_html_interface import AlexaPresentationHtmlInterface

==> ask-smapi-model-1.9.1.tar.gz: ask-smapi-model-1.9.1/ask_smapi_model/v1/skill/manifest/__init__.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the 'License'). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#
from __future__ import absolute_import

from .connections_payload import ConnectionsPayload
from .extension_initialization_request import ExtensionInitializationRequest
from .flash_briefing_update_frequency import FlashBriefingUpdateFrequency
from .skill_manifest_localized_privacy_and_compliance import SkillManifestLocalizedPrivacyAndCompliance
from .music_feature import MusicFeature
from .dialog_delegation_strategy import DialogDelegationStrategy
from .skill_manifest_endpoint import SkillManifestEndpoint
from .video_web_player_feature import VideoWebPlayerFeature
from .authorized_client_lwa_application import AuthorizedClientLwaApplication
from .extension_request import ExtensionRequest
from .voice_profile_feature import VoiceProfileFeature
from .ssl_certificate_type import SSLCertificateType
from .viewport_mode import ViewportMode
from .skill_manifest_events import SkillManifestEvents
from .alexa_for_business_interface_request import AlexaForBusinessInterfaceRequest
from .flash_briefing_content_type import FlashBriefingContentType
from .skill_manifest_privacy_and_compliance import SkillManifestPrivacyAndCompliance
from .authorized_client_lwa import AuthorizedClientLwa
from .interface_type import InterfaceType
from .music_apis import MusicApis
from .distribution_mode import DistributionMode
from .custom_connections import CustomConnections
from .music_capability import MusicCapability
from .display_interface_apml_version import DisplayInterfaceApmlVersion
from .event_name import EventName
from .up_channel_items import UpChannelItems
from .house_hold_list import HouseHoldList
from .music_interfaces import MusicInterfaces
from .permission_name import PermissionName
from .interface import Interface
from .health_interface import HealthInterface
from .region import Region
from .skill_manifest_envelope import SkillManifestEnvelope
from .supported_controls import SupportedControls
from .app_link_interface import AppLinkInterface
from .skill_manifest_apis import SkillManifestApis
from .lambda_endpoint import LambdaEndpoint
from .viewport_specification import ViewportSpecification
from .catalog_info import CatalogInfo
from .music_alias import MusicAlias
from .video_feature import VideoFeature
from .music_content_type import MusicContentType
from .friendly_name import FriendlyName
from .manifest_gadget_support import ManifestGadgetSupport
from .source_language_for_locales import SourceLanguageForLocales
from .dialog_manager import DialogManager
from .video_fire_tv_catalog_ingestion import VideoFireTvCatalogIngestion
from .distribution_countries import DistributionCountries
from .skill_manifest_publishing_information import SkillManifestPublishingInformation
from .gadget_support_requirement import GadgetSupportRequirement
from .video_app_interface import VideoAppInterface
from .custom_apis import CustomApis
from .flash_briefing_genre import FlashBriefingGenre
from .linked_application import LinkedApplication
from .app_link import AppLink
from .localized_flash_briefing_info_items import LocalizedFlashBriefingInfoItems
from .music_wordmark import MusicWordmark
from .knowledge_apis import KnowledgeApis
from .video_apis_locale import VideoApisLocale
from .alexa_for_business_interface import AlexaForBusinessInterface
from .game_engine_interface import GameEngineInterface
from .dialog_management import DialogManagement
from .gadget_controller_interface import GadgetControllerInterface
from .smart_home_protocol import SmartHomeProtocol
from .skill_manifest_localized_publishing_information import SkillManifestLocalizedPublishingInformation
from .version import Version
from .music_request import MusicRequest
from .video_apis import VideoApis
from .lambda_region import LambdaRegion
from .video_country_info import VideoCountryInfo
from .skill_manifest import SkillManifest
from .manifest_version import ManifestVersion
from .flash_briefing_apis import FlashBriefingApis
from .amazon_conversations_dialog_manager import AMAZONConversationsDialogManager
from .permission_items import PermissionItems
from .automatic_distribution import AutomaticDistribution
from .authorized_client import AuthorizedClient
from .event_name_type import EventNameType
from .audio_interface import AudioInterface
from .smart_home_apis import SmartHomeApis
from .alexa_for_business_interface_request_name import AlexaForBusinessInterfaceRequestName
from .app_link_v2_interface import AppLinkV2Interface
from .alexa_for_business_apis import AlexaForBusinessApis
from .video_region import VideoRegion
from .localized_knowledge_information import LocalizedKnowledgeInformation
from .viewport_shape import ViewportShape
from .alexa_presentation_apl_interface import AlexaPresentationAplInterface
from .display_interface import DisplayInterface
from .catalog_type import CatalogType
from .music_content_name import MusicContentName
from .localized_name import LocalizedName
from .authorized_client_lwa_application_android import AuthorizedClientLwaApplicationAndroid
from .custom_localized_information_dialog_management import CustomLocalizedInformationDialogManagement
from .display_interface_template_version import DisplayInterfaceTemplateVersion
from .event_publications import EventPublications
from .demand_response_apis import DemandResponseApis
from .custom_localized_information import CustomLocalizedInformation
from .video_prompt_name_type import VideoPromptNameType
from .video_prompt_name import VideoPromptName
from .custom_task import CustomTask
from .supported_controls_type import SupportedControlsType
from .localized_music_info import LocalizedMusicInfo
from .video_catalog_info import VideoCatalogInfo
from .localized_flash_briefing_info import LocalizedFlashBriefingInfo
from .alexa_presentation_html_interface import AlexaPresentationHtmlInterface
